@@ -13,8 +13,7 @@
 import Listr = require('listr')
 import { Installer } from '../installer'
 import {
-  CheCtlContext,
-  EclipseCheContext,
+  CheCtlContext, EclipseCheContext,
 } from '../../../context'
 import {EclipseCheTasks} from './eclipse-che-tasks'
 import {EclipseChe} from './eclipse-che'
@@ -23,39 +22,20 @@ import {OlmTasks} from '../../olm-tasks'
 import {DELETE_ALL_FLAG, STARTING_CSV_FLAG} from '../../../flags'
 import {isCheFlavor, newListr} from '../../../utils/utls'
 import {DevWorkspaceInstallerFactory} from '../dev-workspace/dev-workspace-installer-factory'
+import {CommonTasks} from '../../common-tasks'
+import {DevWorkspace} from '../dev-workspace/dev-workspace'
+import {Che} from '../../../utils/che'
 
 export class EclipseCheOlmInstaller implements Installer {
   getDeployTasks(): Listr.ListrTask<any> {
     return {
       title: `Deploy ${EclipseChe.PRODUCT_NAME}`,
-      task: async (ctx: any, _task: any) => {
+      task: async (_ctx: any, _task: any) => {
         const tasks = newListr()
-        const flags = CheCtlContext.getFlags()
+        await this.addCommonInstallTasks(tasks)
 
-        // Create a common CatalogSource (IIB) to deploy Dev Workspace operator and DevSpaces from fast channel
-        if (!isCheFlavor() && ctx[EclipseCheContext.CHANNEL] === EclipseChe.NEXT_CHANNEL) {
-          tasks.add(EclipseCheTasks.getCreateImageContentSourcePolicyTask())
-          tasks.add(EclipseCheTasks.getCreateIIBCatalogSourceTask())
-        }
-
-        tasks.add(await EclipseCheTasks.getInstallDevWorkspaceOperatorTask())
-
-        if (isCheFlavor()) {
-          tasks.add(EclipseCheTasks.getCreateEclipseCheCatalogSourceTask())
-        }
-
-        tasks.add(OlmTasks.getCreateSubscriptionTask(
-          EclipseChe.SUBSCRIPTION,
-          ctx[EclipseCheContext.OPERATOR_NAMESPACE],
-          ctx[EclipseCheContext.CATALOG_SOURCE_NAME],
-          ctx[EclipseCheContext.CATALOG_SOURCE_NAMESPACE],
-          ctx[EclipseCheContext.PACKAGE_NAME],
-          ctx[EclipseCheContext.CHANNEL],
-          ctx[EclipseCheContext.APPROVAL_STRATEGY],
-          flags[STARTING_CSV_FLAG]
-        ))
-        tasks.add(OlmTasks.getCreatePrometheusRBACTask())
         tasks.add(OlmTasks.getSetCustomEclipseCheOperatorImageTask())
+        tasks.add(OlmTasks.getCreatePrometheusRBACTask())
         tasks.add(OlmTasks.getFetchCheClusterSampleTask())
         tasks.add(CheClusterTasks.getCreateEclipseCheClusterTask())
         return tasks
@@ -64,21 +44,29 @@ export class EclipseCheOlmInstaller implements Installer {
   }
 
   getPreUpdateTasks(): Listr.ListrTask<any> {
-    return {
-      title: `${EclipseChe.PRODUCT_NAME} operator pre-update check`,
-      task: (_ctx: any, _task: any) => {
-        const tasks = newListr()
-        tasks.add(OlmTasks.getCheckInstallPlanApprovalStrategyTask(EclipseChe.SUBSCRIPTION))
-        return tasks
-      },
-    }
+    return CommonTasks.getDisabledTask()
   }
 
   getUpdateTasks(): Listr.ListrTask<any> {
     return {
       title: `Update ${EclipseChe.PRODUCT_NAME} operator`,
-      task: async (_ctx: any, _task: any) => {
+      task: async (ctx: any, _task: any) => {
         const tasks = newListr()
+
+        if (ctx[EclipseCheContext.CREATE_CATALOG_SOURCE_AND_SUBSCRIPTION]) {
+          tasks.add(await OlmTasks.getDeleteSubscriptionAndCatalogSourceTask(
+            DevWorkspace.PACKAGE,
+            DevWorkspace.CSV_PREFIX,
+            ctx[EclipseCheContext.OPERATOR_NAMESPACE]))
+          tasks.add(await OlmTasks.getDeleteSubscriptionAndCatalogSourceTask(
+            EclipseChe.PACKAGE,
+            EclipseChe.CSV_PREFIX,
+            ctx[EclipseCheContext.OPERATOR_NAMESPACE]))
+
+          await this.addCommonInstallTasks(tasks)
+        }
+
+        tasks.add(OlmTasks.getSetCustomEclipseCheOperatorImageTask())
         tasks.add(OlmTasks.getApproveInstallPlanTask(EclipseChe.SUBSCRIPTION))
         tasks.add(CheClusterTasks.getPatchEclipseCheCluster())
         return tasks
@@ -110,4 +98,33 @@ export class EclipseCheOlmInstaller implements Installer {
       },
     }
   }
+
+  async addCommonInstallTasks(tasks: Listr): Promise<void> {
+    const ctx = CheCtlContext.get()
+    const flags = CheCtlContext.getFlags()
+
+    if (!Che.isRedHatCatalogSources(ctx[EclipseCheContext.CATALOG_SOURCE_NAME])) {
+      if (!isCheFlavor() && ctx[EclipseCheContext.CHANNEL] !== EclipseChe.STABLE_CHANNEL) {
+        tasks.add(EclipseCheTasks.getCreateImageContentSourcePolicyTask())
+      }
+
+      tasks.add(OlmTasks.getCreateCatalogSourceTask(
+        ctx[EclipseCheContext.CATALOG_SOURCE_NAME],
+        ctx[EclipseCheContext.CATALOG_SOURCE_NAMESPACE],
+        ctx[EclipseCheContext.CATALOG_SOURCE_IMAGE]))
+    }
+
+    tasks.add(DevWorkspaceInstallerFactory.getInstaller().getDeployTasks())
+
+    tasks.add(OlmTasks.getCreateSubscriptionTask(
+      EclipseChe.SUBSCRIPTION,
+      ctx[EclipseCheContext.OPERATOR_NAMESPACE],
+      ctx[EclipseCheContext.CATALOG_SOURCE_NAME],
+      ctx[EclipseCheContext.CATALOG_SOURCE_NAMESPACE],
+      ctx[EclipseCheContext.PACKAGE_NAME],
+      ctx[EclipseCheContext.CHANNEL],
+      ctx[EclipseCheContext.APPROVAL_STRATEGY],
+      flags[STARTING_CSV_FLAG]
+    ))
+  }
 }
